intelmq.bots.parsers.malc0de package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.parsers.malc0de package

## Submodules

## intelmq.bots.parsers.malc0de.parser module

IntelMQ parser for Malc0de feeds

`intelmq.bots.parsers.malc0de.parser.` `BOT`

  alias of `intelmq.bots.parsers.malc0de.parser.Malc0deParserBot`

class `intelmq.bots.parsers.malc0de.parser.` `Malc0deParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  `BIND_FORMAT` = {'http://malc0de.com/bl/ZONES', 'https://malc0de.com/bl/ZONES'}
  `IP_BLACKLIST` = {'http://malc0de.com/bl/IP_Blacklist.txt', 'https://malc0de.com/bl/IP_Blacklist.txt'}
  `WINDOWS_FORMAT` = {'http://malc0de.com/bl/BOOT', 'https://malc0de.com/bl/BOOT'}
  `lastgenerated` = None
  `parse_line`(line, report)

    A generator which can yield one or more messages contained in line.

    Report has the full message, thus you can access some metadata. Override for your use.

## Module contents